#!/usr/bin/python
import RPi.GPIO as GPIO
import time, os

LCD_RS = 7
LCD_E  = 8
LCD_D4 = 25
LCD_D5 = 24
LCD_D6 = 23
LCD_D7 = 18

GPIO.setmode(GPIO.BCM)
GPIO.setup(LCD_E,  GPIO.OUT)
GPIO.setup(LCD_RS, GPIO.OUT)
GPIO.setup(LCD_D4, GPIO.OUT)
GPIO.setup(LCD_D5, GPIO.OUT)
GPIO.setup(LCD_D6, GPIO.OUT)
GPIO.setup(LCD_D7, GPIO.OUT)

LCD_WIDTH = 40
LCD_LINE_1 = 0x80
LCD_LINE_2 = 0xC0
LCD_CHR = 1
LCD_CMD = 0
E_PULSE = 0.00005
E_DELAY = 0.00005
pause = 2

HD_1 = "/media/pi/2C33-0235"
HD_2 = "/media/pi/7FDA-61CD"
HD_3 = "/media/pi/8CA8-C35A"

def lcd_enable():
  time.sleep(E_DELAY)
  GPIO.output(LCD_E, 1)
  time.sleep(E_PULSE)
  GPIO.output(LCD_E, 0)
  time.sleep(E_DELAY)

def lcd_byte(bits, mode):
  GPIO.output(LCD_RS, mode)
  GPIO.output(LCD_D4, bits&0x10==0x10)
  GPIO.output(LCD_D5, bits&0x20==0x20)
  GPIO.output(LCD_D6, bits&0x40==0x40)
  GPIO.output(LCD_D7, bits&0x80==0x80)
  lcd_enable()
  GPIO.output(LCD_D4, bits&0x01==0x01)
  GPIO.output(LCD_D5, bits&0x02==0x02)
  GPIO.output(LCD_D6, bits&0x04==0x04)
  GPIO.output(LCD_D7, bits&0x08==0x08)
  lcd_enable()

def lcd_string(message):
  message = message.ljust(LCD_WIDTH," ")
  for i in range(LCD_WIDTH):
    lcd_byte(ord(message[i]),LCD_CHR)

def lcd_anzeige(z1, z2):
  lcd_byte(LCD_LINE_1, LCD_CMD)
  lcd_string(z1)
  lcd_byte(LCD_LINE_2, LCD_CMD)
  lcd_string(z2)

LCD_INIT = [0x33, 0x32, 0x28, 0x0C, 0x06, 0x01]
for i in LCD_INIT:
  lcd_byte(i,LCD_CMD)

try:
  while True:
    s = os.statvfs('/')
    hd1 = os.statvfs(HD_1)
    hd2 = os.statvfs(HD_2)
    hd3 = os.statvfs(HD_3)
    z1 = time.asctime()[0:16]
    z2 = "IP:" + os.popen("hostname -I").readline().split()[0]
    z3 = "SD:" + str(s.f_bsize * s.f_bavail // 1048576).rjust(4," ") + "MB "
    z3 += "U1:" + str(hd1.f_bsize * hd1.f_bavail // 1048576).rjust(4," ") + "MB"
    z4 = "U2:" + str(hd2.f_bsize * hd2.f_bavail // 1048576).rjust(4," ") + "MB "
    z4 += "U3:" + str(hd3.f_bsize * hd3.f_bavail // 1048576).rjust(4," ") + "MB"
    zeile1 = z1.ljust(LCD_WIDTH // 2," ") + z3.ljust(LCD_WIDTH // 2," ")
    zeile2 = z2.ljust(LCD_WIDTH // 2," ") + z4.ljust(LCD_WIDTH // 2," ")
    lcd_anzeige(zeile1, zeile2)
    time.sleep(pause)

except KeyboardInterrupt:
  GPIO.cleanup()
